@@ -7,13 +7,13 @@ use strict;
 
 package XML::Compile::WSS::SecToken;
 use vars '$VERSION';
-$VERSION = '1.09';
+$VERSION = '2.01';
 
 
 use Log::Report 'xml-compile-wss-sig';
 
-use XML::Compile::WSS::Util   qw/XTP10_X509v3 WSU_10 WSM10_BASE64/;
-use MIME::Base64              qw/decode_base64 encode_base64/;
+use XML::Compile::WSS::Util   qw/XTP10_X509v3 WSU_10 :wsm10 :wsm11 XENC_NS/;
+use Scalar::Util   qw/blessed/;
 
 
 sub new(@)
@@ -22,20 +22,24 @@ sub new(@)
     my $type  = delete $args->{type} || XTP10_X509v3;
     if($class eq __PACKAGE__)
     {   if($type =~ /509/)
-        {   eval "require XML::Compile::WSS::SecToken::X509v3"; panic $@ if $@;
-            $class = 'XML::Compile::WSS::SecToken::X509v3';
+        {   $class = 'XML::Compile::WSS::SecToken::X509v3';
         }
         else
         {   error __x"security token type {type} not (yet) supported"
               , type => $type;
         }
+        eval "require $class"; panic $@ if $@;
     }
     (bless {XCWS_type => $type}, $class)->init($args);
 }
 
 sub init($)
 {   my ($self, $args) = @_;
-    $self->{XCWS_id} = $args->{id} || 'my-token';
+    $self->{XCWS_id}   = $args->{id}       || 'my-token';
+    $self->{XCWS_enc}  = $args->{encoding} || WSM10_BASE64;
+    $self->{XCWS_fp}   = $args->{fingerprint};
+    $self->{XCWS_uri}  = $args->{uri}      || '#TOKEN-'.($self+0);
+    $self->{XCWS_name} = $args->{name};
     $self;
 }
 
@@ -43,6 +47,7 @@ sub init($)
 sub fromConfig($%)
 {   my ($class, $config, %args) = @_;
     $args{type} ||= XTP10_X509v3;
+
     return $class->new(%$config, %args)
         if ref $config eq 'HASH';
 
@@ -58,58 +63,18 @@ sub fromConfig($%)
     panic "token configuration `$config' not recognized";
 }
 
-
-sub fromBinSecToken($$)
-{   my ($class, $wss, $data) = @_;
-    my $id  = $data->{wsu_Id};
-    my $key = $data->{_};
-    my $enc = $data->{EncodingType};
-
-    if(!$enc) {}
-    elsif($enc eq WSM10_BASE64) { $key = decode_base64 $key }
-    else {error __x"unsupported data encoding {type} received", type => $enc}
-
-    $class->new(id => $id, type => $data->{ValueType}, binary => $key);
-}
-
 #-----------------
 
-sub id()   {shift->{XCWS_id}}
-sub type() {shift->{XCWS_type}}
+sub id()       {shift->{XCWS_id}}
+sub type()     {shift->{XCWS_type}}
+sub encoding() {shift->{XCWS_enc}}
+
+sub fingerprint{shift->{XCWS_fp}}
+sub uri()      {shift->{XCWS_uri}}
+sub name()     {shift->{XCWS_name}}
 
 #-----------------
 
-sub makeBinSecTokenWriter($)
-{   my ($self, $wss) = @_;
-    my $version = $wss->version; 
-    $version eq '1.1'
-        or error __x"tokens for version {version} not (yet) supported"
-            , version => $version;
-
-    my $schema = $wss->schema;
-    my $ctt    = $schema->findName('wsse:BinarySecurityToken');
-    my $ctw    = $schema->writer($ctt, include_namespaces => 0);
-
-    my ($enc, $data) = $self->asBinary;
-    my %info   =
-      ( EncodingType => $enc
-      , ValueType    => $self->type
-      , _            => $data
-      );
-    my $id  = $self->id;
-
-    sub ($$) {
-       my ($doc, $sec) = @_;
-       my $ct = $ctw->($doc, \%info);
-       $ct->setNamespace(WSU_10, 'wsu', 0);
-       $ct->setAttributeNS(WSU_10, 'Id', $id);
-       $sec->{$ctt} = $ct;
-    }
-}
-
-
-sub asBinary {panic "needs to be extended"}
-
 1;
 
 __END__
