@@ -7,18 +7,16 @@ use strict;
 
 package XML::Compile::WSS::SecToken::X509v3;
 use vars '$VERSION';
-$VERSION = '1.09';
+$VERSION = '2.01';
 
 use base 'XML::Compile::WSS::SecToken';
 
 use Log::Report 'xml-compile-wss-sig';
 
-use XML::Compile::WSS::Util qw/XTP10_X509v3 WSM10_BASE64/;
+use XML::Compile::WSS::Util qw/XTP10_X509v3/;
 
-use MIME::Base64         qw/decode_base64 encode_base64/;
 use Scalar::Util         qw/blessed/;
 use Crypt::OpenSSL::X509 qw/FORMAT_ASN1 FORMAT_PEM/;
-use Crypt::OpenSSL::RSA  ();
 
 
 sub init($)
@@ -26,7 +24,6 @@ sub init($)
     $args->{cert_file} and panic "removed in 1.07, use fromFile()";
 
     $args->{type} ||= XTP10_X509v3;
-    $self->SUPER::init($args);
 
     my $cert;
     if($cert = $args->{certificate}) {}
@@ -37,7 +34,11 @@ sub init($)
     blessed $cert && $cert->isa('Crypt::OpenSSL::X509')
         or error __x"X509 certificate object not supported (yet)";
 
-    $self->{XCWSX_cert} = $cert;
+    $args->{name}        ||= $cert->subject;
+    $args->{fingerprint} ||= $cert->fingerprint_sha1;
+    $self->SUPER::init($args);
+
+    $self->{XCWSX_cert}    = $cert;
     $self;
 }
 
@@ -65,10 +66,6 @@ sub certificate() {shift->{XCWSX_cert}}
 
 #------------------------
 
-sub asBinary()
-{   my $self = shift;
-    my $cert = $self->certificate;
-    ( WSM10_BASE64, encode_base64($cert->as_string(FORMAT_ASN1),'') );
-}
+sub asBinary() {shift->certificate->as_string(FORMAT_ASN1)}
 
 1;
